@@ -1,3 +1,3 @@
-from .definition import LexSubExample, Candidate
+from .definition import Candidate
 from .indexer import Indexer
 from .tokenizer import CustomTokenizer
